import pandas as pd


# Read output from NAMD run
def read_log(fname):
    r"""
    Read output from NAMD.

    Parameters
    ----------
    fname : str
        Name of NAMD output file.

    Returns
    -------
    DataFrame
    """

    # Initialize log info
    columns = None
    records = []

    # Read through log file and extract energy records
    with open(fname, "r") as buf:
        for line in buf:
            # Read first ETITLE
            if columns is None and line.startswith("ETITLE"):
                columns = line.lower().split()[1:]

            # Save each energy record
            if line.startswith("ENERGY"):
                records.append(line.split()[1:])

    # Return
    return pd.DataFrame(records, columns=columns).set_index(columns[0]).astype(float)





from setuptools import setup
import versioneer


# Read in long description
with open('README.rst', 'r') as buf:
    long_description = buf.read()

# Read in requirements.txt
with open('requirements.txt', 'r') as buf:
    requirements = buf.read().splitlines()


# Setup
setup(
    name='namdtools',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    author='C. Lockhart',
    author_email='clockha2@gmu.edu',
    description='A Python interface to NAMD',
    long_description=long_description,
    # long_description_content_type='text/markdown',
    url="https://www.lockhartlab.org",
    packages=[
        'namdtools',
    ],
    install_requires=requirements,
    include_package_data=True,
    zip_safe=True,
)
